@@ -1,9 +1,10 @@
 import shutil
+from collections.abc import Iterator
 from pathlib import Path
-from typing import Iterator
 from unittest.mock import patch
 
 import pytest
+
 from pyconify import _cache, api, get_cache_directory
 
 
